Index: trunk/ppSim/src/ppSimSetPSF.c
===================================================================
--- trunk/ppSim/src/ppSimSetPSF.c	(revision 15005)
+++ trunk/ppSim/src/ppSimSetPSF.c	(revision 17557)
@@ -1,10 +1,12 @@
 # include "ppSim.h"
-static char *defaultModel = "PS_MODEL_GAUSS";
+static char *defaultModel = "PS_MODEL_QGAUSS";
 
 bool ppSimSetPSF (pmChip *chip, pmConfig *config) {
 
-    bool status;
+    bool status, mdok;
     pmPSF *psf = NULL;
     pmTrend2D *param = NULL;
+
+    psMetadata *recipe = psMetadataLookupMetadata(&mdok, config->recipes, PPSIM_RECIPE); // Recipe
 
     // the pmPSF IO functions stores the PSF on the chip->analysis
@@ -14,7 +16,8 @@
     }
 
-    // no supplied PSF, build one using supplied value for seeing
-    // XXX need to correct for the pixel scale
-    float seeing   = psMetadataLookupF32(&status, config->arguments, "SEEING"); // Seeing sigma (pix)
+    // no supplied PSF, build one using supplied value for seeing seeing is already corrected
+    // for the pixel scale, and is converted from FWHM to SIGMA (this is done in
+    // ppSimArguments)
+    float seeing   = psMetadataLookupF32(&status, recipe, "SEEING"); // Seeing SIGMA (pixels)
 
     char *psfModelName = psMetadataLookupStr(&status, config->arguments, "PSF.MODEL"); // Name of PSF model
@@ -50,5 +53,5 @@
     psEllipsePol pol;
 
     // supply the semi-major axis
     axes.major = seeing;
     axes.minor = seeing;
@@ -50,5 +53,5 @@
     psEllipsePol pol;
 
-    // supply the semi-major axis
+    // supply the semi-major axis (these are SIGMA values in PIXELS)
     axes.major = seeing;
     axes.minor = seeing;
